<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Проверка прошла успешно</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Проверка не удалась, у Вас осталась одна попытка</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Подтвердите свой Face ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face ID заблокирован, пожалуйста, используйте пароль</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Устройство недоступно!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Проверка отпечатка пальца</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Проверка прошла успешно</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Проверка не удалась, у Вас осталась одна попытка</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Проверка отпечатков пальцев заблокирована, пожалуйста, введите пароль</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Проверка прошла успешно</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Проверка не удалась, у Вас осталась одна попытка</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Подтвердите свой Iris ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Face ID заблокирован, пожалуйста, используйте пароль</translation>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation>Пожалуйста, подключите ключ безопасности</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Проверка прошла успешно</translation>
    </message>
    <message>
        <source>Verification failed</source>
        <translation>Проверка завершилась неудачно</translation>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation>Пожалуйста, подключите ключ безопасности</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Проверка прошла успешно</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Проверка не удалась, у Вас осталась одна попытка</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Неверный Пароль</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Повторите попытку через 1 минуту.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Сброс пароля</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Забыли пароль?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Повторите попытку через 1 минуту.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Сброс пароля</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Забыли пароль?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Проверка прошла успешно</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Проверка не удалась, у Вас осталась одна попытка</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Неверный PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Запрошен UKey</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Введите Ваш PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Повторите попытку через 1 минуту.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Учетная запись</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Срок действия пароля истек, пожалуйста, измените</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation>Срок действия вашего пароля истек. Пожалуйста, свяжитесь с администратором, чтобы изменить его</translation>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation>Терминал заблокирован, пожалуйста, свяжитесь с администратором</translation>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Неправильный аккаунт</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Неверный Пароль</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation>Обычный режим</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Экран Блокировки</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Не удалось заблокировать экран</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Время проверки отпечатка пальца вышло, пожалуйста, введите свой пароль вручную</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Не удалось сопоставить отпечаток пальца</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Некоторые пользователи по-прежнему находятся в системе и данные будут потеряны после выключения, вы уверены, что хотите выключить?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Некоторые пользователи по-прежнему находятся в системе и данные будут потеряны после перезагрузки, вы уверены, что хотите перезагрузить?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Вы включили высокий уровень безопасности системы, поэтому не можете переключиться в режим Wayland, отключите высокий уровень безопасности в Центре безопасности и повторите попытку.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Спящий режим</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Блокировать</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Переключить пользователя</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Переключить систему</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Обновить и Выключить</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Обновить и Перезагрузить</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Запустить системный монитор</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation>Отправить проверочный код</translation>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation>Пожалуйста, введите Ваш номер телефона</translation>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation>Пожалуйста, введите проверочный код</translation>
    </message>
    <message>
        <source>获取验证码</source>
        <translation>Получить проверочный код</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation>Обновление</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>Пожалуйста, подключитесь, а затем установите обновления.</translation>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Программы препятствуют выключению компьютера, принудительное выключение может привести к потере данных.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Чтобы закрыть программу, нажмите кнопку Отмена, а затем закройте ее.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Программы препятствуют перезагрузке компьютера, принудительная перезагрузка может привести к потере данных.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Программы препятствуют приостановке работы компьютера, принудительная приостановка может привести к потере данных.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Программы препятствуют переходу компьютера в спящий режим, принудительный переход в спящий режим может привести к потере данных.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Программы препятствуют выходу компьютера из системы, принудительный выход из системы может привести к потере данных.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Спящий режим</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Выйти из системы</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Вы уверены, что хотите выключить?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Вы действительно хотите перезагрузить?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Вы действительно хотите выйти из системы?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Обновить и Выключить</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Обновить и Перезагрузить</translation>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation>Закрытие программ и завершение работы, пожалуйста, подождите...</translation>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation>Закрытие программ и перезагрузка, пожалуйста подождите...</translation>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation>Закрытие программ и выход из системы, пожалуйста подождите...</translation>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation>Автоматическая авторизация</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Включить</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Выключить</translation>
    </message>
</context>
</TS>